# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["PortingOrdersActivationJob", "ActivationWindow"]


class ActivationWindow(BaseModel):
    end_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the activation window ends"""

    start_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the activation window starts"""


class PortingOrdersActivationJob(BaseModel):
    id: Optional[str] = None
    """Uniquely identifies this activation job"""

    activate_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the activation job should be executed.

    This time should be between some activation window.
    """

    activation_type: Optional[Literal["scheduled", "on-demand"]] = None
    """Specifies the type of this activation job"""

    activation_windows: Optional[List[ActivationWindow]] = None
    """List of allowed activation windows for this activation job"""

    created_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was created."""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    status: Optional[Literal["created", "in-process", "completed", "failed"]] = None
    """Specifies the status of this activation job"""

    updated_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was created."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["PhoneNumberDeleteResponse", "Data"]


class Data(BaseModel):
    id: Optional[str] = None
    """Identifies the resource."""

    billing_group_id: Optional[str] = None
    """Identifies the billing group associated with the phone number."""

    call_forwarding_enabled: Optional[bool] = None
    """
    Indicates if call forwarding will be enabled for this number if forwards_to and
    forwarding_type are filled in. Defaults to true for backwards compatibility with
    APIV1 use of numbers endpoints.
    """

    call_recording_enabled: Optional[bool] = None
    """Indicates whether call recording is enabled for this number."""

    caller_id_name_enabled: Optional[bool] = None
    """Indicates whether caller ID is enabled for this number."""

    cnam_listing_enabled: Optional[bool] = None
    """Indicates whether a CNAM listing is enabled for this number."""

    connection_id: Optional[str] = None
    """Identifies the connection associated with the phone number."""

    connection_name: Optional[str] = None
    """
    The user-assigned name of the connection to be associated with this phone
    number.
    """

    created_at: Optional[str] = None
    """
    ISO 8601 formatted date indicating when the time it took to activate after the
    purchase.
    """

    customer_reference: Optional[str] = None
    """A customer reference string for customer look ups."""

    deletion_lock_enabled: Optional[bool] = None
    """Indicates whether deletion lock is enabled for this number.

    When enabled, this prevents the phone number from being deleted via the API or
    Telnyx portal.
    """

    emergency_address_id: Optional[str] = None
    """Identifies the emergency address associated with the phone number."""

    emergency_enabled: Optional[bool] = None
    """Indicates whether emergency services are enabled for this number."""

    external_pin: Optional[str] = None
    """
    If someone attempts to port your phone number away from Telnyx and your phone
    number has an external PIN set, Telnyx will attempt to verify that you provided
    the correct external PIN to the winning carrier. Note that not all carriers
    cooperate with this security mechanism.
    """

    messaging_profile_id: Optional[str] = None
    """Identifies the messaging profile associated with the phone number."""

    messaging_profile_name: Optional[str] = None
    """The name of the messaging profile associated with the phone number."""

    phone_number: Optional[str] = None
    """The +E.164-formatted phone number associated with this record."""

    phone_number_type: Optional[Literal["local", "toll_free", "mobile", "national", "shared_cost", "landline"]] = None
    """The phone number's type."""

    purchased_at: Optional[str] = None
    """
    ISO 8601 formatted date indicating the time the request was made to purchase the
    number.
    """

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    status: Optional[
        Literal[
            "purchase-pending",
            "purchase-failed",
            "port-pending",
            "port-failed",
            "active",
            "deleted",
            "emergency-only",
            "ported-out",
            "port-out-pending",
        ]
    ] = None
    """The phone number's current status."""

    t38_fax_gateway_enabled: Optional[bool] = None
    """Indicates whether T38 Fax Gateway for inbound calls to this number."""

    tags: Optional[List[str]] = None
    """A list of user-assigned tags to help manage the phone number."""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date indicating when the resource was updated."""


class PhoneNumberDeleteResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["StreamCodec"]

StreamCodec: TypeAlias = Literal["PCMU", "PCMA", "G722", "OPUS", "AMR-WB", "L16", "default"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.reports import cdr_usage_report_fetch_sync_params
from ...types.reports.cdr_usage_report_fetch_sync_response import CdrUsageReportFetchSyncResponse

__all__ = ["CdrUsageReportsResource", "AsyncCdrUsageReportsResource"]


class CdrUsageReportsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CdrUsageReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return CdrUsageReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CdrUsageReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return CdrUsageReportsResourceWithStreamingResponse(self)

    def fetch_sync(
        self,
        *,
        aggregation_type: Literal["NO_AGGREGATION", "CONNECTION", "TAG", "BILLING_GROUP"],
        product_breakdown: Literal["NO_BREAKDOWN", "DID_VS_TOLL_FREE", "COUNTRY", "DID_VS_TOLL_FREE_PER_COUNTRY"],
        connections: Iterable[float] | Omit = omit,
        end_date: Union[str, datetime] | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CdrUsageReportFetchSyncResponse:
        """Generate and fetch voice usage report synchronously.

        This endpoint will both
        generate and fetch the voice report over a specified time period. No polling is
        necessary but the response may take up to a couple of minutes.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/reports/cdr_usage_reports/sync",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "aggregation_type": aggregation_type,
                        "product_breakdown": product_breakdown,
                        "connections": connections,
                        "end_date": end_date,
                        "start_date": start_date,
                    },
                    cdr_usage_report_fetch_sync_params.CdrUsageReportFetchSyncParams,
                ),
            ),
            cast_to=CdrUsageReportFetchSyncResponse,
        )


class AsyncCdrUsageReportsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCdrUsageReportsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCdrUsageReportsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCdrUsageReportsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncCdrUsageReportsResourceWithStreamingResponse(self)

    async def fetch_sync(
        self,
        *,
        aggregation_type: Literal["NO_AGGREGATION", "CONNECTION", "TAG", "BILLING_GROUP"],
        product_breakdown: Literal["NO_BREAKDOWN", "DID_VS_TOLL_FREE", "COUNTRY", "DID_VS_TOLL_FREE_PER_COUNTRY"],
        connections: Iterable[float] | Omit = omit,
        end_date: Union[str, datetime] | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CdrUsageReportFetchSyncResponse:
        """Generate and fetch voice usage report synchronously.

        This endpoint will both
        generate and fetch the voice report over a specified time period. No polling is
        necessary but the response may take up to a couple of minutes.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/reports/cdr_usage_reports/sync",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "aggregation_type": aggregation_type,
                        "product_breakdown": product_breakdown,
                        "connections": connections,
                        "end_date": end_date,
                        "start_date": start_date,
                    },
                    cdr_usage_report_fetch_sync_params.CdrUsageReportFetchSyncParams,
                ),
            ),
            cast_to=CdrUsageReportFetchSyncResponse,
        )


class CdrUsageReportsResourceWithRawResponse:
    def __init__(self, cdr_usage_reports: CdrUsageReportsResource) -> None:
        self._cdr_usage_reports = cdr_usage_reports

        self.fetch_sync = to_raw_response_wrapper(
            cdr_usage_reports.fetch_sync,
        )


class AsyncCdrUsageReportsResourceWithRawResponse:
    def __init__(self, cdr_usage_reports: AsyncCdrUsageReportsResource) -> None:
        self._cdr_usage_reports = cdr_usage_reports

        self.fetch_sync = async_to_raw_response_wrapper(
            cdr_usage_reports.fetch_sync,
        )


class CdrUsageReportsResourceWithStreamingResponse:
    def __init__(self, cdr_usage_reports: CdrUsageReportsResource) -> None:
        self._cdr_usage_reports = cdr_usage_reports

        self.fetch_sync = to_streamed_response_wrapper(
            cdr_usage_reports.fetch_sync,
        )


class AsyncCdrUsageReportsResourceWithStreamingResponse:
    def __init__(self, cdr_usage_reports: AsyncCdrUsageReportsResource) -> None:
        self._cdr_usage_reports = cdr_usage_reports

        self.fetch_sync = async_to_streamed_response_wrapper(
            cdr_usage_reports.fetch_sync,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    CustomStorageCredentialCreateResponse,
    CustomStorageCredentialUpdateResponse,
    CustomStorageCredentialRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCustomStorageCredentials:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={
                "backend": "gcs",
                "bucket": "example-bucket",
                "credentials": "OPAQUE_CREDENTIALS_TOKEN",
            },
        )
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.custom_storage_credentials.with_raw_response.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = response.parse()
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.custom_storage_credentials.with_streaming_response.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = response.parse()
            assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            client.custom_storage_credentials.with_raw_response.create(
                connection_id="",
                backend="gcs",
                configuration={"backend": "gcs"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.retrieve(
            "connection_id",
        )
        assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.custom_storage_credentials.with_raw_response.retrieve(
            "connection_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = response.parse()
        assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.custom_storage_credentials.with_streaming_response.retrieve(
            "connection_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = response.parse()
            assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            client.custom_storage_credentials.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={
                "backend": "gcs",
                "bucket": "example-bucket",
                "credentials": "OPAQUE_CREDENTIALS_TOKEN",
            },
        )
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.custom_storage_credentials.with_raw_response.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = response.parse()
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.custom_storage_credentials.with_streaming_response.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = response.parse()
            assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            client.custom_storage_credentials.with_raw_response.update(
                connection_id="",
                backend="gcs",
                configuration={"backend": "gcs"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        custom_storage_credential = client.custom_storage_credentials.delete(
            "connection_id",
        )
        assert custom_storage_credential is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.custom_storage_credentials.with_raw_response.delete(
            "connection_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = response.parse()
        assert custom_storage_credential is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.custom_storage_credentials.with_streaming_response.delete(
            "connection_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = response.parse()
            assert custom_storage_credential is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            client.custom_storage_credentials.with_raw_response.delete(
                "",
            )


class TestAsyncCustomStorageCredentials:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={
                "backend": "gcs",
                "bucket": "example-bucket",
                "credentials": "OPAQUE_CREDENTIALS_TOKEN",
            },
        )
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.custom_storage_credentials.with_raw_response.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = await response.parse()
        assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.custom_storage_credentials.with_streaming_response.create(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = await response.parse()
            assert_matches_type(CustomStorageCredentialCreateResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            await async_client.custom_storage_credentials.with_raw_response.create(
                connection_id="",
                backend="gcs",
                configuration={"backend": "gcs"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.retrieve(
            "connection_id",
        )
        assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.custom_storage_credentials.with_raw_response.retrieve(
            "connection_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = await response.parse()
        assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.custom_storage_credentials.with_streaming_response.retrieve(
            "connection_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = await response.parse()
            assert_matches_type(CustomStorageCredentialRetrieveResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            await async_client.custom_storage_credentials.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={
                "backend": "gcs",
                "bucket": "example-bucket",
                "credentials": "OPAQUE_CREDENTIALS_TOKEN",
            },
        )
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.custom_storage_credentials.with_raw_response.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = await response.parse()
        assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.custom_storage_credentials.with_streaming_response.update(
            connection_id="connection_id",
            backend="gcs",
            configuration={"backend": "gcs"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = await response.parse()
            assert_matches_type(CustomStorageCredentialUpdateResponse, custom_storage_credential, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            await async_client.custom_storage_credentials.with_raw_response.update(
                connection_id="",
                backend="gcs",
                configuration={"backend": "gcs"},
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        custom_storage_credential = await async_client.custom_storage_credentials.delete(
            "connection_id",
        )
        assert custom_storage_credential is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.custom_storage_credentials.with_raw_response.delete(
            "connection_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        custom_storage_credential = await response.parse()
        assert custom_storage_credential is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.custom_storage_credentials.with_streaming_response.delete(
            "connection_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            custom_storage_credential = await response.parse()
            assert custom_storage_credential is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `connection_id` but received ''"):
            await async_client.custom_storage_credentials.with_raw_response.delete(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["CommentMarkAsReadResponse", "Data"]


class Data(BaseModel):
    id: Optional[str] = None

    body: Optional[str] = None

    comment_record_id: Optional[str] = None

    comment_record_type: Optional[Literal["sub_number_order", "requirement_group"]] = None

    commenter: Optional[str] = None

    commenter_type: Optional[Literal["admin", "user"]] = None

    created_at: Optional[datetime] = None
    """An ISO 8901 datetime string denoting when the comment was created."""

    read_at: Optional[datetime] = None
    """An ISO 8901 datetime string for when the comment was read."""

    updated_at: Optional[datetime] = None
    """An ISO 8901 datetime string for when the comment was updated."""


class CommentMarkAsReadResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    MobileVoiceConnection,
    MobileVoiceConnectionCreateResponse,
    MobileVoiceConnectionDeleteResponse,
    MobileVoiceConnectionUpdateResponse,
    MobileVoiceConnectionRetrieveResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMobileVoiceConnections:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.create()
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.create(
            active=True,
            connection_name="connection_name",
            inbound={"channel_limit": 0},
            outbound={
                "channel_limit": 0,
                "outbound_voice_profile_id": "outbound_voice_profile_id",
            },
            tags=["string"],
            webhook_api_version="1",
            webhook_event_failover_url="webhook_event_failover_url",
            webhook_event_url="webhook_event_url",
            webhook_timeout_secs=0,
        )
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.mobile_voice_connections.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = response.parse()
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.mobile_voice_connections.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = response.parse()
            assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.retrieve(
            "id",
        )
        assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.mobile_voice_connections.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = response.parse()
        assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.mobile_voice_connections.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = response.parse()
            assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.mobile_voice_connections.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.update(
            id="id",
        )
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.update(
            id="id",
            active=True,
            connection_name="connection_name",
            inbound={"channel_limit": 0},
            outbound={
                "channel_limit": 0,
                "outbound_voice_profile_id": "outbound_voice_profile_id",
            },
            tags=["string"],
            webhook_api_version="1",
            webhook_event_failover_url="webhook_event_failover_url",
            webhook_event_url="webhook_event_url",
            webhook_timeout_secs=0,
        )
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.mobile_voice_connections.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = response.parse()
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.mobile_voice_connections.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = response.parse()
            assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.mobile_voice_connections.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.list()
        assert_matches_type(
            SyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.list(
            filter_connection_name_contains="filter[connection_name][contains]",
            page_number=0,
            page_size=0,
            sort="sort",
        )
        assert_matches_type(
            SyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.mobile_voice_connections.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = response.parse()
        assert_matches_type(
            SyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.mobile_voice_connections.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = response.parse()
            assert_matches_type(
                SyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        mobile_voice_connection = client.mobile_voice_connections.delete(
            "id",
        )
        assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.mobile_voice_connections.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = response.parse()
        assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.mobile_voice_connections.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = response.parse()
            assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.mobile_voice_connections.with_raw_response.delete(
                "",
            )


class TestAsyncMobileVoiceConnections:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.create()
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.create(
            active=True,
            connection_name="connection_name",
            inbound={"channel_limit": 0},
            outbound={
                "channel_limit": 0,
                "outbound_voice_profile_id": "outbound_voice_profile_id",
            },
            tags=["string"],
            webhook_api_version="1",
            webhook_event_failover_url="webhook_event_failover_url",
            webhook_event_url="webhook_event_url",
            webhook_timeout_secs=0,
        )
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_voice_connections.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = await response.parse()
        assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_voice_connections.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = await response.parse()
            assert_matches_type(MobileVoiceConnectionCreateResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.retrieve(
            "id",
        )
        assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_voice_connections.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = await response.parse()
        assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_voice_connections.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = await response.parse()
            assert_matches_type(MobileVoiceConnectionRetrieveResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.mobile_voice_connections.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.update(
            id="id",
        )
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.update(
            id="id",
            active=True,
            connection_name="connection_name",
            inbound={"channel_limit": 0},
            outbound={
                "channel_limit": 0,
                "outbound_voice_profile_id": "outbound_voice_profile_id",
            },
            tags=["string"],
            webhook_api_version="1",
            webhook_event_failover_url="webhook_event_failover_url",
            webhook_event_url="webhook_event_url",
            webhook_timeout_secs=0,
        )
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_voice_connections.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = await response.parse()
        assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_voice_connections.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = await response.parse()
            assert_matches_type(MobileVoiceConnectionUpdateResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.mobile_voice_connections.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.list()
        assert_matches_type(
            AsyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.list(
            filter_connection_name_contains="filter[connection_name][contains]",
            page_number=0,
            page_size=0,
            sort="sort",
        )
        assert_matches_type(
            AsyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_voice_connections.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = await response.parse()
        assert_matches_type(
            AsyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_voice_connections.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = await response.parse()
            assert_matches_type(
                AsyncDefaultFlatPagination[MobileVoiceConnection], mobile_voice_connection, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        mobile_voice_connection = await async_client.mobile_voice_connections.delete(
            "id",
        )
        assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_voice_connections.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_voice_connection = await response.parse()
        assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_voice_connections.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_voice_connection = await response.parse()
            assert_matches_type(MobileVoiceConnectionDeleteResponse, mobile_voice_connection, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.mobile_voice_connections.with_raw_response.delete(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["InsightSettings"]


class InsightSettings(BaseModel):
    insight_group_id: Optional[str] = None
    """Reference to an Insight Group.

    Insights in this group will be run automatically for all the assistant's
    conversations.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["RecordingTranscription"]


class RecordingTranscription(BaseModel):
    id: Optional[str] = None
    """Uniquely identifies the recording transcription."""

    created_at: Optional[str] = None
    """ISO 8601 formatted date indicating when the resource was created."""

    duration_millis: Optional[int] = None
    """The duration of the recording transcription in milliseconds."""

    record_type: Optional[Literal["recording_transcription"]] = None

    recording_id: Optional[str] = None
    """Uniquely identifies the recording associated with this transcription."""

    status: Optional[Literal["in-progress", "completed"]] = None
    """The status of the recording transcription.

    Only `completed` has transcription text available.
    """

    transcription_text: Optional[str] = None
    """The recording's transcribed text."""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date indicating when the resource was updated."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["DocumentUpdateParams"]


class DocumentUpdateParams(TypedDict, total=False):
    customer_reference: str
    """Optional reference string for customer tracking."""

    filename: str
    """The filename of the document."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .number_block_order import NumberBlockOrder

__all__ = ["NumberBlockOrderRetrieveResponse"]


class NumberBlockOrderRetrieveResponse(BaseModel):
    data: Optional[NumberBlockOrder] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .porting_loa_configuration import PortingLoaConfiguration

__all__ = ["LoaConfigurationUpdateResponse"]


class LoaConfigurationUpdateResponse(BaseModel):
    data: Optional[PortingLoaConfiguration] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["SimCardGetPublicIPResponse", "Data"]


class Data(BaseModel):
    created_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was created."""

    ip: Optional[str] = None
    """The provisioned IP address.

    This attribute will only be available when underlying resource status is in a
    "provisioned" status.
    """

    record_type: Optional[str] = None

    region_code: Optional[str] = None

    sim_card_id: Optional[str] = None

    type: Optional[Literal["ipv4"]] = None

    updated_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was updated."""


class SimCardGetPublicIPResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["TfPhoneNumberParam"]


class TfPhoneNumberParam(TypedDict, total=False):
    """A phone number"""

    phone_number: Required[Annotated[str, PropertyInfo(alias="phoneNumber")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference import Conference

__all__ = ["ConferenceRetrieveResponse"]


class ConferenceRetrieveResponse(BaseModel):
    data: Optional[Conference] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import date
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["BillingBundleRetrieveResponse", "Data", "DataBundleLimit"]


class DataBundleLimit(BaseModel):
    id: str

    created_at: date

    metric: str

    service: str

    updated_at: date

    billing_service: Optional[str] = None

    country: Optional[str] = None
    """Use country_iso instead"""

    country_code: Optional[int] = None

    country_iso: Optional[str] = None

    direction: Optional[Literal["inbound", "outbound"]] = None
    """An enumeration."""

    limit: Optional[int] = None

    rate: Optional[str] = None

    types: Optional[List[str]] = None


class Data(BaseModel):
    id: str
    """Bundle's ID, this is used to identify the bundle in the API."""

    active: bool
    """If that bundle is active or not."""

    bundle_limits: List[DataBundleLimit]

    cost_code: str
    """Bundle's cost code, this is used to identify the bundle in the billing system."""

    created_at: date
    """Date the bundle was created."""

    is_public: bool
    """Available to all customers or only to specific customers."""

    name: str
    """Bundle's name, this is used to identify the bundle in the UI."""

    slug: Optional[str] = None
    """Slugified version of the bundle's name."""


class BillingBundleRetrieveResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

from .update_regulatory_requirement_param import UpdateRegulatoryRequirementParam

__all__ = ["NumberOrderPhoneNumberUpdateRequirementsParams"]


class NumberOrderPhoneNumberUpdateRequirementsParams(TypedDict, total=False):
    regulatory_requirements: Iterable[UpdateRegulatoryRequirementParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.texml.accounts import (
    CallCallsResponse,
    CallUpdateResponse,
    CallRetrieveResponse,
    CallSiprecJsonResponse,
    CallStreamsJsonResponse,
    CallRetrieveCallsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCalls:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallRetrieveResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallRetrieveResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallRetrieveResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.retrieve(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.retrieve(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.update(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.update(
            call_sid="call_sid",
            account_sid="account_sid",
            fallback_method="GET",
            fallback_url="https://www.example.com/intruction-c.xml",
            method="GET",
            status="completed",
            status_callback="https://www.example.com/callback",
            status_callback_method="GET",
            texml='<?xml version="1.0" encoding="UTF-8"?><Response><Say>Hello</Say></Response>',
            url="https://www.example.com/intruction-b.xml",
        )
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.update(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.update(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallUpdateResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.update(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.update(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_calls(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        )
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_calls_with_all_params(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
            async_amd=True,
            async_amd_status_callback="https://www.example.com/callback",
            async_amd_status_callback_method="GET",
            caller_id="Info",
            cancel_playback_on_detect_message_end=False,
            cancel_playback_on_machine_detection=False,
            custom_headers=[
                {
                    "name": "X-Custom-Header",
                    "value": "custom-value",
                }
            ],
            detection_mode="Premium",
            fallback_url="https://www.example.com/instructions-fallback.xml",
            machine_detection="Enable",
            machine_detection_silence_timeout=2000,
            machine_detection_speech_end_threshold=2000,
            machine_detection_speech_threshold=2000,
            machine_detection_timeout=5000,
            preferred_codecs="PCMA,PCMU",
            record=False,
            recording_channels="dual",
            recording_status_callback="https://example.com/recording_status_callback",
            recording_status_callback_event="in-progress completed absent",
            recording_status_callback_method="GET",
            recording_timeout=5,
            recording_track="inbound",
            send_recording_url=False,
            sip_auth_password="1234",
            sip_auth_username="user",
            sip_region="Canada",
            status_callback="https://www.example.com/statuscallback-listener",
            status_callback_event="initiated",
            status_callback_method="GET",
            supervise_call_sid="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervising_role="monitor",
            texml='<?xml version="1.0" encoding="UTF-8"?><Response><Say>Hello</Say></Response>',
            trim="trim-silence",
            url="https://www.example.com/texml.xml",
            url_method="GET",
        )
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_calls(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_calls(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallCallsResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_calls(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.calls(
                account_sid="",
                application_sid="example-app-sid",
                from_="+13120001234",
                to="+13121230000",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_calls(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.retrieve_calls(
            account_sid="account_sid",
        )
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_calls_with_all_params(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.retrieve_calls(
            account_sid="account_sid",
            end_time="EndTime",
            end_time_gt="EndTime_gt",
            end_time_lt="EndTime_lt",
            from_="From",
            page=0,
            page_size=0,
            page_token="PageToken",
            start_time="StartTime",
            start_time_gt="StartTime_gt",
            start_time_lt="StartTime_lt",
            status="canceled",
            to="To",
        )
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_calls(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.retrieve_calls(
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_calls(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.retrieve_calls(
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_calls(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.retrieve_calls(
                account_sid="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_siprec_json(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_siprec_json_with_all_params(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
            connector_name="my_connector",
            include_metadata_custom_headers=True,
            name="my_siprec_session",
            secure=True,
            session_timeout_secs=900,
            sip_transport="tcp",
            status_callback="https://www.example.com/callback",
            status_callback_method="GET",
            track="both_tracks",
        )
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_siprec_json(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_siprec_json(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_siprec_json(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.siprec_json(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.siprec_json(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_streams_json(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_streams_json_with_all_params(self, client: Telnyx) -> None:
        call = client.texml.accounts.calls.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
            bidirectional_codec="G722",
            bidirectional_mode="rtp",
            name="My stream",
            status_callback="http://webhook.com/callback",
            status_callback_method="GET",
            track="both_tracks",
            url="wss://www.example.com/websocket",
        )
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_streams_json(self, client: Telnyx) -> None:
        response = client.texml.accounts.calls.with_raw_response.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_streams_json(self, client: Telnyx) -> None:
        with client.texml.accounts.calls.with_streaming_response.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_streams_json(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.streams_json(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            client.texml.accounts.calls.with_raw_response.streams_json(
                call_sid="",
                account_sid="account_sid",
            )


class TestAsyncCalls:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallRetrieveResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallRetrieveResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.retrieve(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallRetrieveResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.retrieve(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.retrieve(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.update(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.update(
            call_sid="call_sid",
            account_sid="account_sid",
            fallback_method="GET",
            fallback_url="https://www.example.com/intruction-c.xml",
            method="GET",
            status="completed",
            status_callback="https://www.example.com/callback",
            status_callback_method="GET",
            texml='<?xml version="1.0" encoding="UTF-8"?><Response><Say>Hello</Say></Response>',
            url="https://www.example.com/intruction-b.xml",
        )
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.update(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallUpdateResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.update(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallUpdateResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.update(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.update(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_calls(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        )
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_calls_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
            async_amd=True,
            async_amd_status_callback="https://www.example.com/callback",
            async_amd_status_callback_method="GET",
            caller_id="Info",
            cancel_playback_on_detect_message_end=False,
            cancel_playback_on_machine_detection=False,
            custom_headers=[
                {
                    "name": "X-Custom-Header",
                    "value": "custom-value",
                }
            ],
            detection_mode="Premium",
            fallback_url="https://www.example.com/instructions-fallback.xml",
            machine_detection="Enable",
            machine_detection_silence_timeout=2000,
            machine_detection_speech_end_threshold=2000,
            machine_detection_speech_threshold=2000,
            machine_detection_timeout=5000,
            preferred_codecs="PCMA,PCMU",
            record=False,
            recording_channels="dual",
            recording_status_callback="https://example.com/recording_status_callback",
            recording_status_callback_event="in-progress completed absent",
            recording_status_callback_method="GET",
            recording_timeout=5,
            recording_track="inbound",
            send_recording_url=False,
            sip_auth_password="1234",
            sip_auth_username="user",
            sip_region="Canada",
            status_callback="https://www.example.com/statuscallback-listener",
            status_callback_event="initiated",
            status_callback_method="GET",
            supervise_call_sid="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervising_role="monitor",
            texml='<?xml version="1.0" encoding="UTF-8"?><Response><Say>Hello</Say></Response>',
            trim="trim-silence",
            url="https://www.example.com/texml.xml",
            url_method="GET",
        )
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_calls(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_calls(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.calls(
            account_sid="account_sid",
            application_sid="example-app-sid",
            from_="+13120001234",
            to="+13121230000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallCallsResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_calls(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.calls(
                account_sid="",
                application_sid="example-app-sid",
                from_="+13120001234",
                to="+13121230000",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_calls(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.retrieve_calls(
            account_sid="account_sid",
        )
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_calls_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.retrieve_calls(
            account_sid="account_sid",
            end_time="EndTime",
            end_time_gt="EndTime_gt",
            end_time_lt="EndTime_lt",
            from_="From",
            page=0,
            page_size=0,
            page_token="PageToken",
            start_time="StartTime",
            start_time_gt="StartTime_gt",
            start_time_lt="StartTime_lt",
            status="canceled",
            to="To",
        )
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_calls(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.retrieve_calls(
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_calls(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.retrieve_calls(
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallRetrieveCallsResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_calls(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.retrieve_calls(
                account_sid="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_siprec_json(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_siprec_json_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
            connector_name="my_connector",
            include_metadata_custom_headers=True,
            name="my_siprec_session",
            secure=True,
            session_timeout_secs=900,
            sip_transport="tcp",
            status_callback="https://www.example.com/callback",
            status_callback_method="GET",
            track="both_tracks",
        )
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_siprec_json(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_siprec_json(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.siprec_json(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallSiprecJsonResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_siprec_json(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.siprec_json(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.siprec_json(
                call_sid="",
                account_sid="account_sid",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_streams_json(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_streams_json_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.texml.accounts.calls.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
            bidirectional_codec="G722",
            bidirectional_mode="rtp",
            name="My stream",
            status_callback="http://webhook.com/callback",
            status_callback_method="GET",
            track="both_tracks",
            url="wss://www.example.com/websocket",
        )
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_streams_json(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.texml.accounts.calls.with_raw_response.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_streams_json(self, async_client: AsyncTelnyx) -> None:
        async with async_client.texml.accounts.calls.with_streaming_response.streams_json(
            call_sid="call_sid",
            account_sid="account_sid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallStreamsJsonResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_streams_json(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `account_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.streams_json(
                call_sid="call_sid",
                account_sid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_sid` but received ''"):
            await async_client.texml.accounts.calls.with_raw_response.streams_json(
                call_sid="",
                account_sid="account_sid",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

from ..._types import SequenceNotStr

__all__ = ["ActionHoldParams"]


class ActionHoldParams(TypedDict, total=False):
    audio_url: str
    """The URL of a file to be played to the participants when they are put on hold.

    media_name and audio_url cannot be used together in one request.
    """

    call_control_ids: SequenceNotStr[str]
    """List of unique identifiers and tokens for controlling the call.

    When empty all participants will be placed on hold.
    """

    media_name: str
    """
    The media_name of a file to be played to the participants when they are put on
    hold. The media_name must point to a file previously uploaded to
    api.telnyx.com/v2/media by the same user/organization. The file must either be a
    WAV or MP3 file.
    """

    region: Literal["Australia", "Europe", "Middle East", "US"]
    """Region where the conference data is located.

    Defaults to the region defined in user's data locality settings (Europe or US).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .voicemail_pref_response import VoicemailPrefResponse

__all__ = ["VoicemailUpdateResponse"]


class VoicemailUpdateResponse(BaseModel):
    data: Optional[VoicemailPrefResponse] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.operator_connect.action_refresh_response import ActionRefreshResponse

__all__ = ["ActionsResource", "AsyncActionsResource"]


class ActionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ActionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return ActionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ActionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return ActionsResourceWithStreamingResponse(self)

    def refresh(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionRefreshResponse:
        """
        This endpoint will make an asynchronous request to refresh the Operator Connect
        integration with Microsoft Teams for the current user. This will create new
        external connections on the user's account if needed, and/or report the
        integration results as
        [log messages](https://developers.telnyx.com/api-reference/external-connections/list-all-log-messages#list-all-log-messages).
        """
        return self._post(
            "/operator_connect/actions/refresh",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionRefreshResponse,
        )


class AsyncActionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncActionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncActionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncActionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncActionsResourceWithStreamingResponse(self)

    async def refresh(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionRefreshResponse:
        """
        This endpoint will make an asynchronous request to refresh the Operator Connect
        integration with Microsoft Teams for the current user. This will create new
        external connections on the user's account if needed, and/or report the
        integration results as
        [log messages](https://developers.telnyx.com/api-reference/external-connections/list-all-log-messages#list-all-log-messages).
        """
        return await self._post(
            "/operator_connect/actions/refresh",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionRefreshResponse,
        )


class ActionsResourceWithRawResponse:
    def __init__(self, actions: ActionsResource) -> None:
        self._actions = actions

        self.refresh = to_raw_response_wrapper(
            actions.refresh,
        )


class AsyncActionsResourceWithRawResponse:
    def __init__(self, actions: AsyncActionsResource) -> None:
        self._actions = actions

        self.refresh = async_to_raw_response_wrapper(
            actions.refresh,
        )


class ActionsResourceWithStreamingResponse:
    def __init__(self, actions: ActionsResource) -> None:
        self._actions = actions

        self.refresh = to_streamed_response_wrapper(
            actions.refresh,
        )


class AsyncActionsResourceWithStreamingResponse:
    def __init__(self, actions: AsyncActionsResource) -> None:
        self._actions = actions

        self.refresh = async_to_streamed_response_wrapper(
            actions.refresh,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .rcs_capabilities import RcsCapabilities

__all__ = ["RcListBulkCapabilitiesResponse"]


class RcListBulkCapabilitiesResponse(BaseModel):
    data: Optional[List[RcsCapabilities]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel
from ..migration_params import MigrationParams

__all__ = ["ActionStopResponse"]


class ActionStopResponse(BaseModel):
    data: Optional[MigrationParams] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CampaignUpdateParams"]


class CampaignUpdateParams(TypedDict, total=False):
    auto_renewal: Annotated[bool, PropertyInfo(alias="autoRenewal")]
    """Help message of the campaign."""

    help_message: Annotated[str, PropertyInfo(alias="helpMessage")]
    """Help message of the campaign."""

    message_flow: Annotated[str, PropertyInfo(alias="messageFlow")]
    """Message flow description."""

    reseller_id: Annotated[str, PropertyInfo(alias="resellerId")]
    """
    Alphanumeric identifier of the reseller that you want to associate with this
    campaign.
    """

    sample1: str
    """Message sample. Some campaign tiers require 1 or more message samples."""

    sample2: str
    """Message sample. Some campaign tiers require 2 or more message samples."""

    sample3: str
    """Message sample. Some campaign tiers require 3 or more message samples."""

    sample4: str
    """Message sample. Some campaign tiers require 4 or more message samples."""

    sample5: str
    """Message sample. Some campaign tiers require 5 or more message samples."""

    webhook_failover_url: Annotated[str, PropertyInfo(alias="webhookFailoverURL")]
    """Webhook failover to which campaign status updates are sent."""

    webhook_url: Annotated[str, PropertyInfo(alias="webhookURL")]
    """Webhook to which campaign status updates are sent."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["DtmfType"]

DtmfType: TypeAlias = Literal["RFC 2833", "Inband", "SIP INFO"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["OAuthClient"]


class OAuthClient(BaseModel):
    client_id: str
    """OAuth client identifier"""

    client_type: Literal["public", "confidential"]
    """OAuth client type"""

    created_at: datetime
    """Timestamp when the client was created"""

    name: str
    """Human-readable name for the OAuth client"""

    org_id: str
    """Organization ID that owns this OAuth client"""

    record_type: Literal["oauth_client"]
    """Record type identifier"""

    require_pkce: bool
    """Whether PKCE (Proof Key for Code Exchange) is required for this client"""

    updated_at: datetime
    """Timestamp when the client was last updated"""

    user_id: str
    """User ID that created this OAuth client"""

    allowed_grant_types: Optional[List[Literal["client_credentials", "authorization_code", "refresh_token"]]] = None
    """List of allowed OAuth grant types"""

    allowed_scopes: Optional[List[str]] = None
    """List of allowed OAuth scopes"""

    client_secret: Optional[str] = None
    """Client secret (only included when available, for confidential clients)"""

    logo_uri: Optional[str] = None
    """URL of the client logo"""

    policy_uri: Optional[str] = None
    """URL of the client's privacy policy"""

    redirect_uris: Optional[List[str]] = None
    """List of allowed redirect URIs"""

    tos_uri: Optional[str] = None
    """URL of the client's terms of service"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .outbound_message_payload import OutboundMessagePayload

__all__ = ["MessageSendGroupMmsResponse"]


class MessageSendGroupMmsResponse(BaseModel):
    data: Optional[OutboundMessagePayload] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ...types import (
    messaging_hosted_number_order_list_params,
    messaging_hosted_number_order_create_params,
    messaging_hosted_number_order_validate_codes_params,
    messaging_hosted_number_order_check_eligibility_params,
    messaging_hosted_number_order_create_verification_codes_params,
)
from .actions import (
    ActionsResource,
    AsyncActionsResource,
    ActionsResourceWithRawResponse,
    AsyncActionsResourceWithRawResponse,
    ActionsResourceWithStreamingResponse,
    AsyncActionsResourceWithStreamingResponse,
)
from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.shared.messaging_hosted_number_order import MessagingHostedNumberOrder
from ...types.messaging_hosted_number_order_create_response import MessagingHostedNumberOrderCreateResponse
from ...types.messaging_hosted_number_order_delete_response import MessagingHostedNumberOrderDeleteResponse
from ...types.messaging_hosted_number_order_retrieve_response import MessagingHostedNumberOrderRetrieveResponse
from ...types.messaging_hosted_number_order_validate_codes_response import (
    MessagingHostedNumberOrderValidateCodesResponse,
)
from ...types.messaging_hosted_number_order_check_eligibility_response import (
    MessagingHostedNumberOrderCheckEligibilityResponse,
)
from ...types.messaging_hosted_number_order_create_verification_codes_response import (
    MessagingHostedNumberOrderCreateVerificationCodesResponse,
)

__all__ = ["MessagingHostedNumberOrdersResource", "AsyncMessagingHostedNumberOrdersResource"]


class MessagingHostedNumberOrdersResource(SyncAPIResource):
    @cached_property
    def actions(self) -> ActionsResource:
        return ActionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> MessagingHostedNumberOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MessagingHostedNumberOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MessagingHostedNumberOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MessagingHostedNumberOrdersResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        messaging_profile_id: str | Omit = omit,
        phone_numbers: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCreateResponse:
        """
        Create a messaging hosted number order

        Args:
          messaging_profile_id: Automatically associate the number with this messaging profile ID when the order
              is complete.

          phone_numbers: Phone numbers to be used for hosted messaging.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/messaging_hosted_number_orders",
            body=maybe_transform(
                {
                    "messaging_profile_id": messaging_profile_id,
                    "phone_numbers": phone_numbers,
                },
                messaging_hosted_number_order_create_params.MessagingHostedNumberOrderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderRetrieveResponse:
        """
        Retrieve a messaging hosted number order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/messaging_hosted_number_orders/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderRetrieveResponse,
        )

    def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[MessagingHostedNumberOrder]:
        """
        List messaging hosted number orders

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/messaging_hosted_number_orders",
            page=SyncDefaultFlatPagination[MessagingHostedNumberOrder],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    messaging_hosted_number_order_list_params.MessagingHostedNumberOrderListParams,
                ),
            ),
            model=MessagingHostedNumberOrder,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderDeleteResponse:
        """
        Delete a messaging hosted number order and all associated phone numbers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/messaging_hosted_number_orders/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderDeleteResponse,
        )

    def check_eligibility(
        self,
        *,
        phone_numbers: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCheckEligibilityResponse:
        """
        Check hosted messaging eligibility

        Args:
          phone_numbers: List of phone numbers to check eligibility

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/messaging_hosted_number_orders/eligibility_numbers_check",
            body=maybe_transform(
                {"phone_numbers": phone_numbers},
                messaging_hosted_number_order_check_eligibility_params.MessagingHostedNumberOrderCheckEligibilityParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCheckEligibilityResponse,
        )

    def create_verification_codes(
        self,
        id: str,
        *,
        phone_numbers: SequenceNotStr[str],
        verification_method: Literal["sms", "call", "flashcall"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCreateVerificationCodesResponse:
        """Create verification codes to validate numbers of the hosted order.

        The
        verification codes will be sent to the numbers of the hosted order.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/messaging_hosted_number_orders/{id}/verification_codes",
            body=maybe_transform(
                {
                    "phone_numbers": phone_numbers,
                    "verification_method": verification_method,
                },
                messaging_hosted_number_order_create_verification_codes_params.MessagingHostedNumberOrderCreateVerificationCodesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCreateVerificationCodesResponse,
        )

    def validate_codes(
        self,
        id: str,
        *,
        verification_codes: Iterable[messaging_hosted_number_order_validate_codes_params.VerificationCode],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderValidateCodesResponse:
        """Validate the verification codes sent to the numbers of the hosted order.

        The
        verification codes must be created in the verification codes endpoint.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/messaging_hosted_number_orders/{id}/validation_codes",
            body=maybe_transform(
                {"verification_codes": verification_codes},
                messaging_hosted_number_order_validate_codes_params.MessagingHostedNumberOrderValidateCodesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderValidateCodesResponse,
        )


class AsyncMessagingHostedNumberOrdersResource(AsyncAPIResource):
    @cached_property
    def actions(self) -> AsyncActionsResource:
        return AsyncActionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMessagingHostedNumberOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMessagingHostedNumberOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        messaging_profile_id: str | Omit = omit,
        phone_numbers: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCreateResponse:
        """
        Create a messaging hosted number order

        Args:
          messaging_profile_id: Automatically associate the number with this messaging profile ID when the order
              is complete.

          phone_numbers: Phone numbers to be used for hosted messaging.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/messaging_hosted_number_orders",
            body=await async_maybe_transform(
                {
                    "messaging_profile_id": messaging_profile_id,
                    "phone_numbers": phone_numbers,
                },
                messaging_hosted_number_order_create_params.MessagingHostedNumberOrderCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderRetrieveResponse:
        """
        Retrieve a messaging hosted number order

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/messaging_hosted_number_orders/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderRetrieveResponse,
        )

    def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[MessagingHostedNumberOrder, AsyncDefaultFlatPagination[MessagingHostedNumberOrder]]:
        """
        List messaging hosted number orders

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/messaging_hosted_number_orders",
            page=AsyncDefaultFlatPagination[MessagingHostedNumberOrder],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    messaging_hosted_number_order_list_params.MessagingHostedNumberOrderListParams,
                ),
            ),
            model=MessagingHostedNumberOrder,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderDeleteResponse:
        """
        Delete a messaging hosted number order and all associated phone numbers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/messaging_hosted_number_orders/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderDeleteResponse,
        )

    async def check_eligibility(
        self,
        *,
        phone_numbers: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCheckEligibilityResponse:
        """
        Check hosted messaging eligibility

        Args:
          phone_numbers: List of phone numbers to check eligibility

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/messaging_hosted_number_orders/eligibility_numbers_check",
            body=await async_maybe_transform(
                {"phone_numbers": phone_numbers},
                messaging_hosted_number_order_check_eligibility_params.MessagingHostedNumberOrderCheckEligibilityParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCheckEligibilityResponse,
        )

    async def create_verification_codes(
        self,
        id: str,
        *,
        phone_numbers: SequenceNotStr[str],
        verification_method: Literal["sms", "call", "flashcall"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderCreateVerificationCodesResponse:
        """Create verification codes to validate numbers of the hosted order.

        The
        verification codes will be sent to the numbers of the hosted order.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/messaging_hosted_number_orders/{id}/verification_codes",
            body=await async_maybe_transform(
                {
                    "phone_numbers": phone_numbers,
                    "verification_method": verification_method,
                },
                messaging_hosted_number_order_create_verification_codes_params.MessagingHostedNumberOrderCreateVerificationCodesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderCreateVerificationCodesResponse,
        )

    async def validate_codes(
        self,
        id: str,
        *,
        verification_codes: Iterable[messaging_hosted_number_order_validate_codes_params.VerificationCode],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessagingHostedNumberOrderValidateCodesResponse:
        """Validate the verification codes sent to the numbers of the hosted order.

        The
        verification codes must be created in the verification codes endpoint.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/messaging_hosted_number_orders/{id}/validation_codes",
            body=await async_maybe_transform(
                {"verification_codes": verification_codes},
                messaging_hosted_number_order_validate_codes_params.MessagingHostedNumberOrderValidateCodesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessagingHostedNumberOrderValidateCodesResponse,
        )


class MessagingHostedNumberOrdersResourceWithRawResponse:
    def __init__(self, messaging_hosted_number_orders: MessagingHostedNumberOrdersResource) -> None:
        self._messaging_hosted_number_orders = messaging_hosted_number_orders

        self.create = to_raw_response_wrapper(
            messaging_hosted_number_orders.create,
        )
        self.retrieve = to_raw_response_wrapper(
            messaging_hosted_number_orders.retrieve,
        )
        self.list = to_raw_response_wrapper(
            messaging_hosted_number_orders.list,
        )
        self.delete = to_raw_response_wrapper(
            messaging_hosted_number_orders.delete,
        )
        self.check_eligibility = to_raw_response_wrapper(
            messaging_hosted_number_orders.check_eligibility,
        )
        self.create_verification_codes = to_raw_response_wrapper(
            messaging_hosted_number_orders.create_verification_codes,
        )
        self.validate_codes = to_raw_response_wrapper(
            messaging_hosted_number_orders.validate_codes,
        )

    @cached_property
    def actions(self) -> ActionsResourceWithRawResponse:
        return ActionsResourceWithRawResponse(self._messaging_hosted_number_orders.actions)


class AsyncMessagingHostedNumberOrdersResourceWithRawResponse:
    def __init__(self, messaging_hosted_number_orders: AsyncMessagingHostedNumberOrdersResource) -> None:
        self._messaging_hosted_number_orders = messaging_hosted_number_orders

        self.create = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.list,
        )
        self.delete = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.delete,
        )
        self.check_eligibility = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.check_eligibility,
        )
        self.create_verification_codes = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.create_verification_codes,
        )
        self.validate_codes = async_to_raw_response_wrapper(
            messaging_hosted_number_orders.validate_codes,
        )

    @cached_property
    def actions(self) -> AsyncActionsResourceWithRawResponse:
        return AsyncActionsResourceWithRawResponse(self._messaging_hosted_number_orders.actions)


class MessagingHostedNumberOrdersResourceWithStreamingResponse:
    def __init__(self, messaging_hosted_number_orders: MessagingHostedNumberOrdersResource) -> None:
        self._messaging_hosted_number_orders = messaging_hosted_number_orders

        self.create = to_streamed_response_wrapper(
            messaging_hosted_number_orders.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            messaging_hosted_number_orders.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            messaging_hosted_number_orders.list,
        )
        self.delete = to_streamed_response_wrapper(
            messaging_hosted_number_orders.delete,
        )
        self.check_eligibility = to_streamed_response_wrapper(
            messaging_hosted_number_orders.check_eligibility,
        )
        self.create_verification_codes = to_streamed_response_wrapper(
            messaging_hosted_number_orders.create_verification_codes,
        )
        self.validate_codes = to_streamed_response_wrapper(
            messaging_hosted_number_orders.validate_codes,
        )

    @cached_property
    def actions(self) -> ActionsResourceWithStreamingResponse:
        return ActionsResourceWithStreamingResponse(self._messaging_hosted_number_orders.actions)


class AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse:
    def __init__(self, messaging_hosted_number_orders: AsyncMessagingHostedNumberOrdersResource) -> None:
        self._messaging_hosted_number_orders = messaging_hosted_number_orders

        self.create = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.delete,
        )
        self.check_eligibility = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.check_eligibility,
        )
        self.create_verification_codes = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.create_verification_codes,
        )
        self.validate_codes = async_to_streamed_response_wrapper(
            messaging_hosted_number_orders.validate_codes,
        )

    @cached_property
    def actions(self) -> AsyncActionsResourceWithStreamingResponse:
        return AsyncActionsResourceWithStreamingResponse(self._messaging_hosted_number_orders.actions)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["BrandTriggerSMSOtpParams"]


class BrandTriggerSMSOtpParams(TypedDict, total=False):
    pin_sms: Required[Annotated[str, PropertyInfo(alias="pinSms")]]
    """SMS message template to send the OTP.

    Must include `@OTP_PIN@` placeholder which will be replaced with the actual PIN
    """

    success_sms: Required[Annotated[str, PropertyInfo(alias="successSms")]]
    """SMS message to send upon successful OTP verification"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["PhoneNumberExtensionCreateParams", "ActivationRange", "ExtensionRange"]


class PhoneNumberExtensionCreateParams(TypedDict, total=False):
    activation_ranges: Required[Iterable[ActivationRange]]
    """Specifies the activation ranges for this porting phone number extension.

    The activation range must be within the extension range and should not overlap
    with other activation ranges.
    """

    extension_range: Required[ExtensionRange]

    porting_phone_number_id: Required[str]
    """
    Identifies the porting phone number associated with this porting phone number
    extension.
    """


class ActivationRange(TypedDict, total=False):
    end_at: Required[int]
    """Specifies the end of the activation range.

    It must be no more than the end of the extension range.
    """

    start_at: Required[int]
    """Specifies the start of the activation range.

    Must be greater or equal the start of the extension range.
    """


class ExtensionRange(TypedDict, total=False):
    end_at: Required[int]
    """
    Specifies the end of the extension range for this porting phone number
    extension.
    """

    start_at: Required[int]
    """
    Specifies the start of the extension range for this porting phone number
    extension.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["LogMessageListParams", "Filter", "FilterTelephoneNumber"]


class LogMessageListParams(TypedDict, total=False):
    filter: Filter
    """Filter parameter for log messages (deepObject style).

    Supports filtering by external_connection_id and telephone_number with
    eq/contains operations.
    """

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]


class FilterTelephoneNumber(TypedDict, total=False):
    """Telephone number filter operations for log messages.

    Use 'eq' for exact matches or 'contains' for partial matches.
    """

    contains: str
    """The partial phone number to filter log messages for. Requires 3-15 digits."""

    eq: str
    """
    The phone number to filter log messages for or "null" to filter for logs without
    a phone number
    """


class Filter(TypedDict, total=False):
    """Filter parameter for log messages (deepObject style).

    Supports filtering by external_connection_id and telephone_number with eq/contains operations.
    """

    external_connection_id: str
    """
    The external connection ID to filter by or "null" to filter for logs without an
    external connection ID
    """

    telephone_number: FilterTelephoneNumber
    """Telephone number filter operations for log messages.

    Use 'eq' for exact matches or 'contains' for partial matches.
    """
